@@ -4,11 +4,11 @@ use 5.008005;
 use strict;
 use warnings;
 use IO::File             ();
-use Params::Util         ();
-use ORLite::Mirror       ();
+use Params::Util         1.00 ();
+use ORLite::Mirror       1.20 ();
 use CPANDB::Distribution ();
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 sub import {
 	my $class  = shift;
